==> zio-aws-amplifyuibuilder_3-5.19.31.2-sources.jar: zio/aws/amplifyuibuilder/model/PutMetadataFlagRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class PutMetadataFlagRequest(
    appId: String,
    body: zio.aws.amplifyuibuilder.model.PutMetadataFlagBody,
    environmentName: String,
    featureName: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest = {
    import PutMetadataFlagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
      .builder()
      .appId(appId: java.lang.String)
      .body(body.buildAwsValue())
      .environmentName(environmentName: java.lang.String)
      .featureName(featureName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.wrap(buildAwsValue())
}
object PutMetadataFlagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest =
      zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest(
        appId,
        body.asEditable,
        environmentName,
        featureName
      )
    def appId: String
    def body: zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly
    def environmentName: String
    def featureName: String
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getBody: ZIO[
      Any,
      Nothing,
      zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly
    ] = ZIO.succeed(body)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getFeatureName: ZIO[Any, Nothing, String] = ZIO.succeed(featureName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ) extends zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val body
        : zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly =
      zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.wrap(impl.body())
    override val environmentName: String = impl.environmentName(): String
    override val featureName: String = impl.featureName(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ): zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifyuibuilder_3-7.21.15.13-sources.jar: zio/aws/amplifyuibuilder/model/PutMetadataFlagRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class PutMetadataFlagRequest(
    appId: String,
    environmentName: String,
    featureName: String,
    body: zio.aws.amplifyuibuilder.model.PutMetadataFlagBody
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest = {
    import PutMetadataFlagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .featureName(featureName: java.lang.String)
      .body(body.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.wrap(buildAwsValue())
}
object PutMetadataFlagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest =
      zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest(
        appId,
        environmentName,
        featureName,
        body.asEditable
      )
    def appId: String
    def environmentName: String
    def featureName: String
    def body: zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getFeatureName: ZIO[Any, Nothing, String] = ZIO.succeed(featureName)
    def getBody: ZIO[
      Any,
      Nothing,
      zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly
    ] = ZIO.succeed(body)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ) extends zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
    override val featureName: String = impl.featureName(): String
    override val body
        : zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.ReadOnly =
      zio.aws.amplifyuibuilder.model.PutMetadataFlagBody.wrap(impl.body())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.PutMetadataFlagRequest
  ): zio.aws.amplifyuibuilder.model.PutMetadataFlagRequest.ReadOnly =
    new Wrapper(impl)
}
